import * as React from 'react';
import { Animated } from 'react-native';
export declare const MENU_OPEN_DURATION = 150;
export interface FloatingMenuState {
    optionsContainerAnim: Animated.Value;
    isMenuOpen: boolean;
}
export interface FloatingMenuProps {
    /**
     * List of items to display in the popup menu.
     */
    items: Array<FloatingMenuItem>;
    /**
     * Whether to highlight the currently selected menu item. Defaults to true.
     */
    showSelectedIndicator?: boolean;
    /**
     * Whether to automatically close the popup menu when an item is selected. Defaults to true.
     */
    closeOnSelect?: boolean;
    /**
     * Currently selected @see FloatingMenuItem .
     */
    selectedItem: FloatingMenuItem;
    /**
     * Callback invoked when an item is selected in the popup menu.
     */
    onSelectItem: (item: FloatingMenuItem) => void;
}
export interface FloatingMenuItem {
    name: string;
    value: string | number;
}
export default class FloatingMenu extends React.Component<FloatingMenuProps, FloatingMenuState> {
    static defaultProps: {
        showSelectedItemIndicator: boolean;
        closeMenuOnSelect: boolean;
    };
    state: {
        optionsContainerAnim: Animated.Value;
        isMenuOpen: boolean;
    };
    /**
     * Indicates whether the collapsible menu is currently visible.
     */
    readonly isOpen: boolean;
    /**
     * Toggle the visibility of the collapsible menu.
     */
    toggleMenu: () => void;
    private onSelectOption;
    render(): JSX.Element;
}
